@@ -1,10 +1,8 @@
 function _aws_cdk_aws_mediaconnect_CfnFlowVpcInterfaceProps(p) {
 }
-function _aws_cdk_aws_mediaconnect_CfnFlowSourceProps(p) {
-}
 function _aws_cdk_aws_mediaconnect_CfnFlowEntitlementProps(p) {
 }
-function _aws_cdk_aws_mediaconnect_CfnFlowOutputProps(p) {
+function _aws_cdk_aws_mediaconnect_CfnFlowSourceProps(p) {
 }
 function _aws_cdk_aws_mediaconnect_CfnFlowProps(p) {
     if (p == null)
@@ -14,6 +12,8 @@ function _aws_cdk_aws_mediaconnect_CfnFlowProps(p) {
         _aws_cdk_aws_mediaconnect_CfnFlow_SourceProperty(p.source);
     visitedObjects.delete(p);
 }
+function _aws_cdk_aws_mediaconnect_CfnFlowOutputProps(p) {
+}
 function _aws_cdk_aws_mediaconnect_CfnFlowVpcInterface(p) {
 }
 function _aws_cdk_aws_mediaconnect_CfnFlowSource(p) {
@@ -53,5 +53,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_mediaconnect_CfnFlowVpcInterfaceProps, _aws_cdk_aws_mediaconnect_CfnFlowSourceProps, _aws_cdk_aws_mediaconnect_CfnFlowEntitlementProps, _aws_cdk_aws_mediaconnect_CfnFlowOutputProps, _aws_cdk_aws_mediaconnect_CfnFlowProps, _aws_cdk_aws_mediaconnect_CfnFlowVpcInterface, _aws_cdk_aws_mediaconnect_CfnFlowSource, _aws_cdk_aws_mediaconnect_CfnFlowSource_EncryptionProperty, _aws_cdk_aws_mediaconnect_CfnFlowEntitlement, _aws_cdk_aws_mediaconnect_CfnFlowEntitlement_EncryptionProperty, _aws_cdk_aws_mediaconnect_CfnFlow, _aws_cdk_aws_mediaconnect_CfnFlow_FailoverConfigProperty, _aws_cdk_aws_mediaconnect_CfnFlow_EncryptionProperty, _aws_cdk_aws_mediaconnect_CfnFlowOutput, _aws_cdk_aws_mediaconnect_CfnFlowOutput_VpcInterfaceAttachmentProperty, _aws_cdk_aws_mediaconnect_CfnFlowOutput_EncryptionProperty, _aws_cdk_aws_mediaconnect_CfnFlow_SourceProperty };
+module.exports = { print, _aws_cdk_aws_mediaconnect_CfnFlowVpcInterfaceProps, _aws_cdk_aws_mediaconnect_CfnFlowEntitlementProps, _aws_cdk_aws_mediaconnect_CfnFlowSourceProps, _aws_cdk_aws_mediaconnect_CfnFlowProps, _aws_cdk_aws_mediaconnect_CfnFlowOutputProps, _aws_cdk_aws_mediaconnect_CfnFlowVpcInterface, _aws_cdk_aws_mediaconnect_CfnFlowSource, _aws_cdk_aws_mediaconnect_CfnFlowSource_EncryptionProperty, _aws_cdk_aws_mediaconnect_CfnFlowEntitlement, _aws_cdk_aws_mediaconnect_CfnFlowEntitlement_EncryptionProperty, _aws_cdk_aws_mediaconnect_CfnFlow, _aws_cdk_aws_mediaconnect_CfnFlow_FailoverConfigProperty, _aws_cdk_aws_mediaconnect_CfnFlow_EncryptionProperty, _aws_cdk_aws_mediaconnect_CfnFlowOutput, _aws_cdk_aws_mediaconnect_CfnFlowOutput_VpcInterfaceAttachmentProperty, _aws_cdk_aws_mediaconnect_CfnFlowOutput_EncryptionProperty, _aws_cdk_aws_mediaconnect_CfnFlow_SourceProperty };
 module.exports.DeprecationError = DeprecationError;
